// aes.h (version  6.0.0)
//
// For C/C++ compilers supporting the "declspec" keyword.
//
// STATIC_LIBRARY must be defined if linking with aes32.obj or aes64.obj

#ifdef STATIC_LIBRARY
  #define DLL_IMPORT_EXPORT
#else
  #ifdef DLL_SOURCE_CODE
     #define DLL_IMPORT_EXPORT __declspec(dllexport) __stdcall
  #else
     #define DLL_IMPORT_EXPORT __declspec(dllimport) __stdcall
  #endif
#endif

#ifdef __cplusplus
  #define NoMangle extern "C"
#else
  #define NoMangle
#endif

#define AES_BLOCK_SIZE           16  // block size of AES is fixed at 16 bytes
#define AES_KEY_SIZE             32  // key size is always 32 bytes (for 256-bit AES)

#define AES_GET_CONTROL_VERSION 101 // get AES control block version
#define AES_GET_CONTROL_SIZE    102 // get size of AES control block
#define AES_GET_VERSION         103 // get AES version
#define AES_GET_BUILD           104 // get AES build
#define AES_GET_SECURE_SIZE     105 // get size of secure random control block

#define AES_GET_REGISTRATION    201 // get registration string

#define AES_ECB_MODE              0 // use ECB mode (default)
#define AES_CBC_MODE              2 // use CBC mode

#define AES_ENCRYPT               0 // encrypt (default)
#define AES_DECRYPT               4 // decrypt

#define AES_PAD_ZERO              6 // pad with 0's
#define AES_PAD_SPACE             7 // pad with spaces (0x20)
#define AES_PAD_RANDOM            8 // pad with random values
#define AES_PAD_PKCS7             9 // pad according to PKCS7

#define AES_NIBBLE_METHOD         0 // use "nibble" method to create encryption key
#define AES_SHA256_METHOD         1 // use SHA 256 to create encryption key
#define AES_MIXED_METHOD          2 // do nibble method followed by SHA256 method

#define AES_PKCS7_MASK         0x01 // uses PKCS7 padding if bit = 1

#define AES_SET_SEED              1

//  error codes

#define AES_NOT_MULTIPLE         -2 // not multiple of 16 bytes
#define AES_BAD_KEY_DIR          -3 // key direction is invalid
#define AES_BAD_KEY_DATA         -4 // key data is invalid
#define AES_BAD_CIPHER_MODE      -5 // invalid cipher mode
#define AES_BAD_CIPHER_STATE     -6 // cipher not initialized
#define AES_BAD_BLOCK_LENGTH     -7 // invalid block length
#define AES_NOT_INITIALIZED      -8 // AES control block not initialized
#define AES_IS_CORRUPTED         -9 // AES control block is corrupted
#define AES_INTERNAL_ERROR      -10 // AES internal error
#define AES_BAD_PASS_LEN        -11 // password too short
#define AES_CANNOT_OPEN         -12 // cannot open file
#define AES_CANNOT_CREATE       -13 // cannot create file
#define AES_READ_ERROR          -14 // read error
#define AES_WRITE_ERROR         -15 // write error
#define AES_BAD_PAD_CHOICE      -16 // must be AES_PAD_*
#define AES_BAD_HEX_CHAR        -17 // bad hex character
#define AES_UNEXPECTED_CHAR     -18 // unexpected character
#define AES_ATTACH_CALL         -19 // aesAttach not called
#define AES_NULL_POINTER        -20 // unexpected null pointer
#define AES_BAD_METHOD          -21 // bad method
#define AES_BUFFER_TOO_SMALL    -22 // buffer is too small
#define AES_BUFFER_TOO_BIG      -23 // buffer is too big
#define AES_PKCS7_ERROR         -24 // PKCS7 padding error
#define AES_CANNOT_OPEN_WRITE   -25 // cannot open file for write
#define AES_CANNOT_CLOSE        -26 // cannot close file
#define AES_CANNOT_DELETE       -27 // cannot delete file

#define AES_ABORTED           (-201)
#define AES_KEYCODE           (-202)
#define AES_EXPIRED           (-203)

NoMangle int DLL_IMPORT_EXPORT aesAttach(int, int);
NoMangle int DLL_IMPORT_EXPORT aesByteToHex(char *, int, char *);
NoMangle int DLL_IMPORT_EXPORT aesDecodeBase64(char *, int, char *);
NoMangle int DLL_IMPORT_EXPORT aesDecryptBlocks(char *, char *, int, char *);
NoMangle int DLL_IMPORT_EXPORT aesDecryptBuffer(char *, char *, int, char *);
NoMangle int DLL_IMPORT_EXPORT aesDecryptFile(char *, char *, char *);
NoMangle int DLL_IMPORT_EXPORT aesEncodeBase64(char *, int, char *);
NoMangle int DLL_IMPORT_EXPORT aesEncryptBlocks(char *, char *, int, char *);
NoMangle int DLL_IMPORT_EXPORT aesEncryptBuffer(char *, char *, int, char *);
NoMangle int DLL_IMPORT_EXPORT aesEncryptFile(char *, char *, char *);
NoMangle int DLL_IMPORT_EXPORT aesEncryptWrite(char *,char *,int, char *);
NoMangle int DLL_IMPORT_EXPORT aesErrorText(int, char *, int);
NoMangle int DLL_IMPORT_EXPORT aesGetInteger(char *, int);
NoMangle int DLL_IMPORT_EXPORT aesGetString(char *, int, char *, int);
NoMangle int DLL_IMPORT_EXPORT aesHexToByte(char *, int, char *);
NoMangle int DLL_IMPORT_EXPORT aesInitAES(char *, char *, int, int, char *);
NoMangle int DLL_IMPORT_EXPORT aesMakeKeyPair(char *, char *);
NoMangle int DLL_IMPORT_EXPORT aesMakeRandom(char *, int);
NoMangle int DLL_IMPORT_EXPORT aesMakeSharedKey(char *, char *, char *, char *);
NoMangle int DLL_IMPORT_EXPORT aesMakeUserKey(char *, char *, int);
NoMangle int DLL_IMPORT_EXPORT aesPadBuffer(char *, int, int);
NoMangle int DLL_IMPORT_EXPORT aesReadDecrypt(char *,char *, char *,int);
NoMangle int DLL_IMPORT_EXPORT aesRemovePad(char *, int);
NoMangle int DLL_IMPORT_EXPORT aesSaltPass(unsigned int, int, char *, char *, char *);
NoMangle int DLL_IMPORT_EXPORT aesSecureRandom(char *, char *, int);
NoMangle int DLL_IMPORT_EXPORT aesSetInteger(char *, int, int);
NoMangle int DLL_IMPORT_EXPORT aesSha256(char *, char *);
NoMangle int DLL_IMPORT_EXPORT aesSha256Data(char *, int, char *);
NoMangle int DLL_IMPORT_EXPORT aesSha256File(char *, char *);
NoMangle int DLL_IMPORT_EXPORT aesShredFile(char *, int);
NoMangle int DLL_IMPORT_EXPORT aesSleep(int);
NoMangle int DLL_IMPORT_EXPORT aesVerifyControl(char *);
NoMangle int DLL_IMPORT_EXPORT aesXorBits(char *, int, char *, char *, int);
